==> office-ui-fabric-vue-7.0.19.tgz: package/lib/components/Button/CompoundButton/CompoundButton.styles.js <==
import { memoizeFunction } from '@uifabric-vue/utilities';
import { FontWeights, HighContrastSelector } from '@uifabric/styling';
import { concatStyleSets } from '@uifabric/merge-styles';
import { getStyles as getStyles$1 } from '../BaseButton.styles.js';
import { getStyles as getStyles$2 } from '../SplitButton/SplitButton.styles.js';
import { primaryStyles, standardStyles } from '../ButtonThemes.js';

const getStyles = memoizeFunction((theme, customStyles, primary) => {
  const {
    fonts,
    palette
  } = theme;
  const baseButtonStyles = getStyles$1(theme);
  const splitButtonStyles = getStyles$2(theme);
  const compoundButtonStyles = {
    root: {
      maxWidth: '280px',
      minHeight: '72px',
      height: 'auto',
      padding: '16px 12px'
    },
    flexContainer: {
      flexDirection: 'row',
      alignItems: 'flex-start',
      minWidth: '100%',
      margin: ''
    },
    textContainer: {
      textAlign: 'left'
    },
    icon: {
      fontSize: '2em',
      lineHeight: '1em',
      height: '1em',
      margin: '0px 8px 0px 0px',
      flexBasis: '1em',
      flexShrink: '0'
    },
    label: {
      margin: '0 0 5px',
      lineHeight: '100%',
      fontWeight: FontWeights.semibold
    },
    description: [fonts.small, {
      lineHeight: '100%'
    }]
  };
  const standardCompoundTheme = {
    description: {
      color: palette.neutralSecondary
    },
    descriptionHovered: {
      color: palette.neutralDark
    },
    descriptionPressed: {
      color: 'inherit'
    },
    descriptionChecked: {
      color: 'inherit'
    },
    descriptionDisabled: {
      color: 'inherit'
    }
  };
  const primaryCompoundTheme = {
    description: {
      color: palette.white,
      selectors: {
        [HighContrastSelector]: {
          backgroundColor: 'WindowText',
          color: 'Window',
          MsHighContrastAdjust: 'none'
        }
      }
    },
    descriptionHovered: {
      color: palette.white,
      selectors: {
        [HighContrastSelector]: {
          backgroundColor: 'Highlight',
          color: 'Window'
        }
      }
    },
    descriptionPressed: {
      color: 'inherit',
      selectors: {
        [HighContrastSelector]: {
          color: 'Window',
          backgroundColor: 'WindowText',
          MsHighContrastAdjust: 'none'
        }
      }
    },
    descriptionChecked: {
      color: 'inherit',
      selectors: {
        [HighContrastSelector]: {
          color: 'Window',
          backgroundColor: 'WindowText',
          MsHighContrastAdjust: 'none'
        }
      }
    },
    descriptionDisabled: {
      color: 'inherit',
      selectors: {
        [HighContrastSelector]: {
          color: 'inherit'
        }
      }
    }
  }; // @ts-ignore

  return concatStyleSets(baseButtonStyles, compoundButtonStyles, primary ? primaryStyles(theme) : standardStyles(theme), primary ? primaryCompoundTheme : standardCompoundTheme, splitButtonStyles, customStyles);
});

export { getStyles };

==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Button/CompoundButton/CompoundButton.styles.js <==
import { memoizeFunction } from '@uifabric-vue/utilities';
import { FontWeights, HighContrastSelector } from '@uifabric/styling';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { concatStyleSets } from '@uifabric/merge-styles';
import '../../node_modules/core-js/modules/es.string.small.js';
import { getStyles as getStyles$1 } from '../BaseButton.styles.js';
import { getStyles as getStyles$2 } from '../SplitButton/SplitButton.styles.js';
import { primaryStyles, standardStyles } from '../ButtonThemes.js';

var getStyles = memoizeFunction(function (theme, customStyles, primary) {
  var fonts = theme.fonts,
      palette = theme.palette;
  var baseButtonStyles = getStyles$1(theme);
  var splitButtonStyles = getStyles$2(theme);
  var compoundButtonStyles = {
    root: {
      maxWidth: '280px',
      minHeight: '72px',
      height: 'auto',
      padding: '16px 12px'
    },
    flexContainer: {
      flexDirection: 'row',
      alignItems: 'flex-start',
      minWidth: '100%',
      margin: ''
    },
    textContainer: {
      textAlign: 'left'
    },
    icon: {
      fontSize: '2em',
      lineHeight: '1em',
      height: '1em',
      margin: '0px 8px 0px 0px',
      flexBasis: '1em',
      flexShrink: '0'
    },
    label: {
      margin: '0 0 5px',
      lineHeight: '100%',
      fontWeight: FontWeights.semibold
    },
    description: [fonts.small, {
      lineHeight: '100%'
    }]
  };
  var standardCompoundTheme = {
    description: {
      color: palette.neutralSecondary
    },
    descriptionHovered: {
      color: palette.neutralDark
    },
    descriptionPressed: {
      color: 'inherit'
    },
    descriptionChecked: {
      color: 'inherit'
    },
    descriptionDisabled: {
      color: 'inherit'
    }
  };
  var primaryCompoundTheme = {
    description: {
      color: palette.white,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'WindowText',
        color: 'Window',
        MsHighContrastAdjust: 'none'
      })
    },
    descriptionHovered: {
      color: palette.white,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'Highlight',
        color: 'Window'
      })
    },
    descriptionPressed: {
      color: 'inherit',
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'Window',
        backgroundColor: 'WindowText',
        MsHighContrastAdjust: 'none'
      })
    },
    descriptionChecked: {
      color: 'inherit',
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'Window',
        backgroundColor: 'WindowText',
        MsHighContrastAdjust: 'none'
      })
    },
    descriptionDisabled: {
      color: 'inherit',
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'inherit'
      })
    }
  };
  return concatStyleSets(baseButtonStyles, compoundButtonStyles, primary ? primaryStyles(theme) : standardStyles(theme), primary ? primaryCompoundTheme : standardCompoundTheme, splitButtonStyles, customStyles);
});

export { getStyles };
